import { BroadcastsRecorderEvents } from './types';
import { Context } from './context';
interface Broadcast {
    procedureName: string;
    contextState: Context & any;
    data?: any;
}
/**
 * Is the controller that can be plugged into a EventManager to store/dump/read the broadcast history
 * of the said EventManager.
 */
export declare class BroadcastsRecorder {
    private readonly __eventEmitter;
    /**
     * @private The list of broadcasts that still haven't been dumped
     */
    private __undumpedBroadcasts;
    /**
     * The total amount of stored undumped broadcasts
     */
    get size(): number;
    /**
     * The index of the last read message
     */
    readOffset: number;
    /**
     * Reads an entry from the records
     * Beware that unbound methods or getters/setters are not saved on the records.
     * @param index the index of the record to be read
     */
    read(index?: number): Broadcast | undefined;
    /**
     * The next offset that the method .read() will use
     */
    get nextOffset(): number;
    /**
     * Writes the state to the undumped broadcast list
     * @param procedureName
     * @param contextState
     * @param data Optional
     * @WARNING Writing directly to this will make this instance record a change
     * that did not happen!
     */
    writeState(procedureName: string, contextState: Context, data?: any): void;
    /**
     * Reads the list of recorded broadcasts and clears it.
     * Beware that unbound methods or getters/setters are not saved on the records.
     */
    dump(): Broadcast[];
    /**
     * Listens to an event that is emitted by this BroadcastsRecorder instance
     * @param event The event to listen to.
     * @param callback The callback to be executed when the event is emitted.
     */
    on(event: BroadcastsRecorderEvents, callback: (broadcasts: Broadcast[]) => void): this;
    /**
     * Removes a listener from this BroadcastsRecorder instance
     * @param event The event to remove listener from.
     * @param callback The listener callback.
     */
    off(event: BroadcastsRecorderEvents, callback: (broadcasts: Broadcast[]) => void): this;
}
export {};
