import { Birbable, HandlerFunction, TriggerOptions } from './types';
declare type ContextOptions = {
    identifier: string | symbol;
    errorHandler?: HandlerFunction;
};
declare type ContextData<T extends Object> = Partial<T>;
/**
 * Context defines a group of domain information. It available to a Procedure when
 * it gets executed. A context may have any Bibrbable instance signed on it.
 */
export declare class Context<D = any> {
    /**
     * @readonly @private identifier of the context entity
     */
    private readonly __identifier;
    /**
     * @readonly @private error handler of errors that might happen
     * while executing proedures
     */
    private __errorHandler?;
    /**
     * @readonly @private Map of Birbables registered in the context
     */
    private readonly __birbables;
    private readonly __contextState;
    /**
     * The current state data of the context
     */
    get contextState(): ContextData<D>;
    /**
     * Sets a state to the context
     * @param information The object information to be set
     */
    setContextState(information: ContextData<D>): this;
    /**
     * @returns identifier of the context entity
     */
    get identifier(): string | symbol;
    set errorHandler(handler: HandlerFunction);
    /**
     * @param identifier The value to set the local identifier of the context
     */
    constructor(contextOtions: ContextOptions);
    /**
     * Triggers the execution of a signed `Birbable`.
     * @param name Identifier of what needs to be triggered in this context
     * @param descriptable Additional Information to be sent to the Birbable
     * @param errorHandler A function to catch errors in case of unexpected promise Rejections
     */
    trigger<K>(options: TriggerOptions, descriptable?: K): this;
    private __activeErrorHandler;
    /**
     * Removes a birbable which is about to be triggered
     * @private
     * @param birbable
     */
    private __unmount;
    /**
     * Removes a whole group of birbables
     * @private
     * @param group a symbol marking the group to be removed
     */
    private __clearGroup;
    /**
     * Signs a Birbable in your context. Only signed Birbables can be triggered
     * @param birbable
     */
    sign(birbable: Birbable): this;
    /**
     * Usigns a Birbable from the context.
     * @param birbable Any Birbable that was signed before in this context
     */
    unsign(birbable: Birbable): this;
}
export {};
