import { Birbable, TriggerOptions } from './types';
import { BroadcastsRecorder } from './broadcasts-recorder';
import { Context } from './context';
/**
 * Holds Contexts and broadcasts events to them
 */
export declare class EventManager {
    /**
     * @private
     * @readonly A Map of added contexts
     */
    private readonly __contexts;
    /**
     * @public
     * @readonly The dump controller for this instance of the EventManager
     */
    readonly broadcasts?: BroadcastsRecorder;
    constructor(broadcasts?: BroadcastsRecorder);
    /**
     * Adds a context to this event manager.
     * @param context
     */
    addContext(context: Context): EventManager;
    /**
     * Removes a context from this event manager.
     * @param contexName
     */
    removeContext(contexName: string | symbol): EventManager;
    /**
     * Broadcasts a Birbable to a specific context on this manager, or to all of them
     * @param options The configuration for this broadcast
     * @param descriptable Optional - Additional info to be sent to the Birbable
     */
    broadcast<T>(options: TriggerOptions, descriptable?: T): EventManager;
    /**
     * Signs a Birbable to a Context
     * @param birbable The birbable to add
     * @param context The context to add the birbable to
     */
    addBirbable(birbable: Birbable, context: string | symbol): EventManager;
    /**
     * Removes a Birbable from a Context
     * @param birbable The birbable to remove
     * @param context The context to remove the birbable from
     */
    removeBirbable(birbable: Birbable, context: string | symbol): EventManager;
}
