"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * Holds Contexts and broadcasts events to them
 */
var EventManager = /** @class */ (function () {
    function EventManager(broadcasts) {
        /**
         * @private
         * @readonly A Map of added contexts
         */
        this.__contexts = new Map();
        this.broadcasts = broadcasts;
    }
    /**
     * Adds a context to this event manager.
     * @param context
     */
    EventManager.prototype.addContext = function (context) {
        this.__contexts.set(context.identifier, context);
        return this;
    };
    /**
     * Removes a context from this event manager.
     * @param contexName
     */
    EventManager.prototype.removeContext = function (contexName) {
        this.__contexts.delete(contexName);
        return this;
    };
    /**
     * Broadcasts a Birbable to a specific context on this manager, or to all of them
     * @param options The configuration for this broadcast
     * @param descriptable Optional - Additional info to be sent to the Birbable
     */
    EventManager.prototype.broadcast = function (options, descriptable) {
        var _this = this;
        var _a;
        var chosenContext = (options.context !== undefined) ?
            this.__contexts.get(options.context) : undefined;
        if (chosenContext === undefined) {
            this.__contexts.forEach(function (currentContext) {
                var _a;
                currentContext.trigger(options, descriptable);
                (_a = _this.broadcasts) === null || _a === void 0 ? void 0 : _a.writeState(options.birbable, currentContext, descriptable);
            });
            return this;
        }
        chosenContext.trigger(options, descriptable);
        (_a = this.broadcasts) === null || _a === void 0 ? void 0 : _a.writeState(options.birbable, chosenContext, descriptable);
        return this;
    };
    /**
     * Signs a Birbable to a Context
     * @param birbable The birbable to add
     * @param context The context to add the birbable to
     */
    EventManager.prototype.addBirbable = function (birbable, context) {
        this.__contexts.get(context).sign(birbable);
        return this;
    };
    /**
     * Removes a Birbable from a Context
     * @param birbable The birbable to remove
     * @param context The context to remove the birbable from
     */
    EventManager.prototype.removeBirbable = function (birbable, context) {
        this.__contexts.get(context).unsign(birbable);
        return this;
    };
    return EventManager;
}());
exports.EventManager = EventManager;
;
