import { BirbsOption, BirbsRunnable } from './types';
import { Context } from './context';
import { Procedure } from './procedure';
/**
 * Birbable entity used to run a sequence of Procedures
 * @abstract
 */
export declare abstract class Pipeline extends BirbsRunnable {
    /**
     * A property used to assert the type of the Birbable
     * @readonly
     */
    readonly __type = "PIPELINE";
    private readonly steps;
    private readonly onFinish?;
    /**
     * Adds a step to the pipeline
     * @param procedure The next procedure to execute
     */
    addStep(procedure: Procedure): Pipeline;
    /**
     * @param options Options to build the new Pipeline
     * @param onFinish Callback executed when the pipeline finishes. Recieves the context as an argument
     * @param onFail Callback executed when a step fails
     */
    constructor(options: BirbsOption, onFinish?: CallableFunction);
    private runPipeline;
    /**
     * When working with Pipeline's execute method, prefer to pass
     * the context type that you are working with so it is possible to
     * assert the type that you're working with
     */
    execute<T>(context: Context, descriptable?: T): Promise<void>;
}
