import { Context } from './context';
import { Pipeline } from './pipeline';
import { Procedure } from './procedure';
export declare type HandlerFunction = (error: Error) => void;
export declare type TriggerOptions = {
    context?: symbol | string;
    birbable: string;
    errorHandler?: HandlerFunction;
};
/**
 * The base class that a context uses to trigger events.
 * @abstract
 */
export declare abstract class BirbsRunnable {
    private readonly __lifetime;
    private readonly __group?;
    /**
     * The lifespan of the Birbable Entity
     * can be either 'SINGLE' or 'DURABLE'
     */
    get lifetime(): Lifetime;
    /**
     * The Birbable group of the procedure or pipeline.
     * Only a single procedure of a group may be executed at a time, others of the
     * same group will be discarded when one is emitted.
     */
    get group(): symbol;
    abstract execute(context: Context, descriptable?: unknown): Promise<void>;
    constructor(options?: BirbsOption);
    /**
     * @returns a Boolean representing if the entity belongs to any group
     */
    get belongsToGroup(): boolean;
}
export declare type Lifetime = 'DURABLE' | 'SINGLE';
export declare type BirbsOption = {
    lifetime: Lifetime;
    group?: symbol;
};
export declare type Birbable = Procedure | Pipeline;
export declare enum BroadcastsRecorderEvents {
    WRITE = "write",
    DUMP = "dump",
    READ = "read"
}
